@@ -13,7 +13,10 @@
 
 #include <AkonadiCore/ServerManager>
 
+#include <kcoreaddons_version.h>
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <Kdelibs4ConfigMigrator>
+#endif
 
 #include <KWindowSystem>
 #include <QDBusConnection>
@@ -21,9 +24,11 @@
 NotesAgent::NotesAgent(const QString &id)
     : Akonadi::AgentBase(id)
 {
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
     Kdelibs4ConfigMigrator migrate(QStringLiteral("notesagent"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_notes_agentrc") << QStringLiteral("akonadi_notes_agent.notifyrc"));
     migrate.migrate();
+#endif
 
     mNotesManager = new NotesManager(this);
     new NotesAgentAdaptor(this);
