@@ -1,5 +1,6 @@
 /*
    SPDX-FileCopyrightText: 2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021 Alexander Lohnau <alexander.lohnau@gmx.de>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -29,8 +30,8 @@
 #include <QVBoxLayout>
 #include <QWhatsThis>
 
-KNoteDisplayConfig::KNoteDisplayConfig(QWidget *parent)
-    : KCModule(parent)
+KNoteDisplayConfig::KNoteDisplayConfig(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     auto lay = new QVBoxLayout(this);
     QWidget *w = new KNoteDisplayConfigWidget(true);
@@ -50,8 +51,8 @@ void KNoteDisplayConfig::save()
     KCModule::save();
 }
 
-KNoteEditorConfig::KNoteEditorConfig(QWidget *parent)
-    : KCModule(parent)
+KNoteEditorConfig::KNoteEditorConfig(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     auto lay = new QVBoxLayout(this);
     QWidget *w = new KNoteEditorConfigWidget(this);
@@ -71,27 +72,27 @@ void KNoteEditorConfig::load()
     KCModule::load();
 }
 
-KNoteMiscConfig::KNoteMiscConfig(QWidget *parent)
-    : KCModule(parent)
+KNoteMiscConfig::KNoteMiscConfig(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     auto lay = new QVBoxLayout(this);
     lay->setContentsMargins(0, 0, 0, 0);
 
-    QCheckBox *kcfg_SystemTrayShowNotes = new QCheckBox(i18n("Show number of notes in tray icon"), this);
+    auto kcfg_SystemTrayShowNotes = new QCheckBox(i18n("Show number of notes in tray icon"), this);
 
     kcfg_SystemTrayShowNotes->setObjectName(QStringLiteral("kcfg_SystemTrayShowNotes"));
     lay->addWidget(kcfg_SystemTrayShowNotes);
 
     auto hbox = new QHBoxLayout;
     lay->addLayout(hbox);
-    QLabel *label_DefaultTitle = new QLabel(i18n("Default Title:"), this);
+    auto label_DefaultTitle = new QLabel(i18n("Default Title:"), this);
     hbox->addWidget(label_DefaultTitle);
 
     mDefaultTitle = new QLineEdit(this);
     label_DefaultTitle->setBuddy(mDefaultTitle);
     hbox->addWidget(mDefaultTitle);
 
-    QLabel *howItWorks = new QLabel(i18n("<a href=\"whatsthis\">How does this work?</a>"));
+    auto howItWorks = new QLabel(i18n("<a href=\"whatsthis\">How does this work?</a>"));
     connect(howItWorks, &QLabel::linkActivated, this, &KNoteMiscConfig::slotHelpLinkClicked);
     lay->addWidget(howItWorks);
     addConfig(KNotesGlobalConfig::self(), this);
@@ -138,16 +139,16 @@ void KNoteMiscConfig::slotHelpLinkClicked(const QString &)
     QWhatsThis::showText(QCursor::pos(), help);
 }
 
-KNotePrintConfig::KNotePrintConfig(QWidget *parent)
-    : KCModule(parent)
+KNotePrintConfig::KNotePrintConfig(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     auto lay = new QVBoxLayout(this);
-    QWidget *w = new QWidget(this);
+    auto w = new QWidget(this);
     lay->addWidget(w);
     auto layout = new QGridLayout(w);
     layout->setContentsMargins(0, 0, 0, 0);
 
-    QLabel *label_PrintAction = new QLabel(i18n("Theme:"), this);
+    auto label_PrintAction = new QLabel(i18n("Theme:"), this);
     layout->addWidget(label_PrintAction, 0, 0);
 
     mSelectTheme = new KNotePrintSelectThemeComboBox(this);
@@ -193,8 +194,8 @@ void KNotePrintConfig::defaults()
     Q_EMIT changed(true);
 }
 
-KNoteCollectionConfig::KNoteCollectionConfig(QWidget *parent)
-    : KCModule(parent)
+KNoteCollectionConfig::KNoteCollectionConfig(QWidget *parent, const QVariantList &args)
+    : KCModule(parent, args)
 {
     auto lay = new QHBoxLayout(this);
     mCollectionConfigWidget = new KNoteCollectionConfigWidget;
