@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef SUMMARYWIDGET_H
-#define SUMMARYWIDGET_H
+#pragma once
 
 #include <AkonadiCore/Item>
 
@@ -73,4 +72,3 @@ private:
     bool mInProgress = false;
 };
 
-#endif
