@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #include "knotegrantleeprint.h"
 #include "print/knoteprintobject.h"
 
-#include <AkonadiCore/Item>
 #include <Akonadi/Notes/NoteUtils>
+#include <AkonadiCore/Item>
 
 #include <KMime/Message>
 
@@ -70,10 +70,11 @@ void KNotesGrantleePrintTest::shouldDisplayNoteInfo()
     msg->assemble();
 
     QList<KNotePrintObject *> lst;
-    auto *obj = new KNotePrintObject(note);
+    auto obj = new KNotePrintObject(note);
     lst << obj;
     const QString html = grantleePrint.notesToHtml(lst);
     QCOMPARE(html, result);
+    qDeleteAll(lst);
 }
 
-QTEST_MAIN(KNotesGrantleePrintTest)
+QTEST_GUILESS_MAIN(KNotesGrantleePrintTest)
