@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef KNOTESGRANTLEEPRINTTEST_H
-#define KNOTESGRANTLEEPRINTTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -23,4 +22,3 @@ private Q_SLOTS:
     void shouldDisplayNoteInfo();
 };
 
-#endif // KNOTESGRANTLEEPRINTTEST_H
